"""
Configs migration

Generation datetime: 2021-07-28 09:47:09.572302
"""

from configs_core.migration.db_migrate_helper import DatabaseMigrationHelper

mh: DatabaseMigrationHelper

REVISION = "780ab891"
DOWN_REVISION = "1d02fbdf"


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to add
    mh.addLimitation(
        limitationName="LUNA_IMAGE_STORE_OBJECTS_ADDRESS",
        validationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
                "bucket": {"type": "string"},
            },
            "required": ["origin", "api_version", "bucket"],
            "additionalProperties": False,
        },
        defaultValue={
            "origin": "http://127.0.0.1:5020",
            "api_version": 1,
            "bucket": "visionlabs-objects",
        },
        description="Address of service for storing objects",
        services=["luna-api"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_IMAGE_STORE_OBJECTS_TIMEOUTS",
        validationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        defaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        description="timeouts for http-request to luna-image-store service",
        services=["luna-api"],
        groupNames=["luna-platform"],
    )


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to remove
    mh.removeLimitation(limitationName="LUNA_IMAGE_STORE_OBJECTS_ADDRESS")
    mh.removeLimitation(limitationName="LUNA_IMAGE_STORE_OBJECTS_TIMEOUTS")
