"""
Configs migration

Generation datetime: 2023-03-29 07:59:11.975637
"""

from typing import List

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "2d2d20de"
DOWN_REVISION = "7105eb7e"


def faceDetectorSettingUpgradeFunction(setting: dict):
    setting["estimator_settings"]["redetect_face_target_size"] = 64
    return setting


def faceDetectorSettingDowngradeFunction(setting: dict):
    setting["estimator_settings"]["redetect_face_target_size"] = 45
    return setting


def bodyDetectorSettingUpgradeFunction(setting: dict):
    setting["estimator_settings"]["score_threshold"] = 0.5
    return setting


def bodyDetectorSettingDowngradeFunction(setting: dict):
    setting["estimator_settings"]["score_threshold"] = 0.3
    return setting


limitationsToModify: List[LimitationToModify] = [
    LimitationToModify(
        limitationName="LUNA_HANDLERS_BODY_DETECTOR_SETTINGS",
        oldDefaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            },
            "estimator_settings": {
                "image_size": 640,
                "redetect_score_threshold": 0.12,
                "score_threshold": 0.3,
                "landmarks17_threshold": 0.25,
            },
        },
        newDefaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            },
            "estimator_settings": {
                "image_size": 640,
                "redetect_score_threshold": 0.12,
                "score_threshold": 0.5,
                "landmarks17_threshold": 0.25,
            },
        },
        settingUpgradeFunction=bodyDetectorSettingUpgradeFunction,
        settingDowngradeFunction=bodyDetectorSettingDowngradeFunction,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-handlers"],
        newServices=["luna-handlers"],
    ),
    LimitationToModify(
        limitationName="LUNA_HANDLERS_FACE_DETECTOR_SETTINGS",
        oldDefaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            },
            "estimator_settings": {
                "min_face_size": 50,
                "redetect_tensor_size": 80,
                "redetect_face_target_size": 45,
                "redetect_score_threshold": 0.3,
                "score_threshold": 0.42,
            },
        },
        newDefaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            },
            "estimator_settings": {
                "min_face_size": 50,
                "redetect_tensor_size": 80,
                "redetect_face_target_size": 64,
                "redetect_score_threshold": 0.3,
                "score_threshold": 0.42,
            },
        },
        settingUpgradeFunction=faceDetectorSettingUpgradeFunction,
        settingDowngradeFunction=faceDetectorSettingDowngradeFunction,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-handlers"],
        newServices=["luna-handlers"],
    ),
]

externalLimitationsToModify: List[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
