"""
Configs migration

Generation datetime: 2023-05-25 07:04:40.861762
"""

from typing import List

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "13582cfd"
DOWN_REVISION = "35ddecdf"


limitationsToModify: List[LimitationToModify] = [
    LimitationToModify(
        limitationName="EXTERNAL_LUNA_API_ADDRESS",
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-api", "luna-handlers", "luna-tasks"],
        newServices=["luna-api", "luna-handlers", "luna-remote-sdk", "luna-tasks"],
    ),
    LimitationToModify(
        limitationName="LUNA_IMAGE_STORE_IMAGES_ADDRESS",
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-admin", "luna-api", "luna-handlers", "luna-tasks"],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-remote-sdk",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="ADDITIONAL_SERVICES_USAGE",
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-tasks",
        ],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_IMAGE_STORE_BODIES_SAMPLES_ADDRESS",
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-admin", "luna-api", "luna-handlers", "luna-tasks"],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-remote-sdk",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_IMAGE_STORE_FACES_SAMPLES_ADDRESS",
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-admin", "luna-api", "luna-handlers", "luna-tasks"],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-remote-sdk",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_HANDLERS_LOAD_EXTERNAL_IMAGES_TIMEOUT",
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-handlers"],
        newServices=["luna-handlers", "luna-remote-sdk"],
    ),
    LimitationToModify(
        limitationName="LUNA_IMAGE_STORE_IMAGES_TIMEOUTS",
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-api", "luna-handlers", "luna-tasks"],
        newServices=["luna-api", "luna-handlers", "luna-remote-sdk", "luna-tasks"],
    ),
    LimitationToModify(
        limitationName="LUNA_IMAGE_STORE_BODIES_SAMPLES_TIMEOUTS",
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-api", "luna-handlers", "luna-tasks"],
        newServices=["luna-api", "luna-handlers", "luna-remote-sdk", "luna-tasks"],
    ),
    LimitationToModify(
        limitationName="LUNA_IMAGE_STORE_FACES_SAMPLES_TIMEOUTS",
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-api", "luna-handlers", "luna-tasks"],
        newServices=["luna-api", "luna-handlers", "luna-remote-sdk", "luna-tasks"],
    ),
]

externalLimitationsToModify: List[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
