"""
Configs migration

Generation datetime: 2023-06-29 09:33:34.594339
"""

from typing import List

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "c51cdfac"
DOWN_REVISION = "45ccc5c8"


def settingUpgradeFunction(s3Setting):
    if "bucket" in s3Setting:
        del s3Setting["bucket"]
    return s3Setting


def settingDowngradeFunction(s3Setting):
    s3Setting["bucket"] = "lis_bucket"
    return s3Setting


limitationsToModify: List[LimitationToModify] = [
    LimitationToModify(
        limitationName="S3",
        oldValidationSchema={
            "properties": {
                "host": {"type": "string"},
                "region": {"type": "string"},
                "aws_public_access_key": {"type": "string"},
                "aws_secret_access_key": {"type": "string"},
                "authorization_signature": {"type": "string", "enum": ["s3v2", "s3v4"]},
                "request_timeout": {"type": "integer"},
                "connect_timeout": {"type": "integer"},
                "bucket": {"type": "string"},
                "verify_ssl": {"type": "boolean"},
            },
            "required": [
                "host",
                "aws_public_access_key",
                "aws_secret_access_key",
                "authorization_signature",
            ],
            "type": "object",
            "additionalProperties": False,
        },
        newValidationSchema={
            "properties": {
                "host": {"type": "string"},
                "region": {"type": "string"},
                "aws_public_access_key": {"type": "string"},
                "aws_secret_access_key": {"type": "string"},
                "authorization_signature": {"type": "string", "enum": ["s3v2", "s3v4"]},
                "request_timeout": {"type": "integer"},
                "connect_timeout": {"type": "integer"},
                "verify_ssl": {"type": "boolean"},
            },
            "required": [
                "host",
                "aws_public_access_key",
                "aws_secret_access_key",
                "authorization_signature",
            ],
            "type": "object",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "host": "http://localhost:7480",
            "region": "",
            "aws_public_access_key": "",
            "aws_secret_access_key": "",
            "authorization_signature": "s3v4",
            "request_timeout": 60,
            "connect_timeout": 30,
            "bucket": "lis_bucket",
            "verify_ssl": True,
        },
        newDefaultValue={
            "host": "http://localhost:7480",
            "region": "",
            "aws_public_access_key": "",
            "aws_secret_access_key": "",
            "authorization_signature": "s3v4",
            "request_timeout": 60,
            "connect_timeout": 30,
            "verify_ssl": True,
        },
        settingUpgradeFunction=settingUpgradeFunction,
        settingDowngradeFunction=settingDowngradeFunction,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-image-store"],
        newServices=["luna-image-store"],
    ),
]

externalLimitationsToModify: List[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
