"""
Configs migration

Generation datetime: 2025-03-18 12:43:16.790162+00:00
"""

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "cb4a9d71"
DOWN_REVISION = "9dcf50f6"


limitationsToModify: list[LimitationToModify] = [
    LimitationToModify(
        limitationName="LUNA_SENDER_TIMEOUTS",
        settingUpgradeFunction=lambda oldValue: oldValue,
        settingDowngradeFunction=lambda oldValue: oldValue,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-video-agent"],
        newServices=["luna-api", "luna-video-agent"],
    ),
    LimitationToModify(
        limitationName="LUNA_API_ADDRESS",
        settingUpgradeFunction=lambda oldValue: oldValue,
        settingDowngradeFunction=lambda oldValue: oldValue,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-admin", "luna-backport3", "luna-backport4"],
        newServices=[
            "luna-admin",
            "luna-backport3",
            "luna-backport4",
            "luna-video-agent",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_API_TIMEOUTS",
        settingUpgradeFunction=lambda oldValue: oldValue,
        settingDowngradeFunction=lambda oldValue: oldValue,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-backport3", "luna-backport4"],
        newServices=["luna-backport3", "luna-backport4", "luna-video-agent"],
    ),
]

externalLimitationsToModify: list[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
